@@ -21,16 +21,11 @@ class ConnectionError(Exception):
     pass
 
 
-def create_connection(host: str, database: str, user: str, password: str, port: int = 5432, postgres_credentials: PostgresCredentials | None = None) -> psycopg2.connect:
+def create_connection(postgres_credentials: PostgresCredentials) -> psycopg2.connect:
     """Create a connection to the database.
 
     Args:
-        host (str): The host of the database.
-        database (str): The name of the database.
-        user (str): The user to connect to the database.
-        password (str): The password of the user.
-        port (int, optional): The port of the database. Defaults to 5432.
-        postgres_credentials (PostgresCredentials, optional): The Postgres credentials class to use to access credentials.
+        postgres_credentials (PostgresCredentials): The Postgres credentials class to use to access credentials.
 
     Raises:
         ConnectionError: If the connection fails.
@@ -38,17 +33,24 @@ def create_connection(host: str, database: str, user: str, password: str, port:
     Returns:
         psycopg2.connection: The connection to the database.
     """
+    if not postgres_credentials:
+        raise ConnectionError('Credentials must be provided.')
     try:
-        if postgres_credentials:
-            host = postgres_credentials.host
-            database = postgres_credentials.database
-            user = postgres_credentials.user
-            password = postgres_credentials.password
-        return psycopg2.connect(host=host, database=database, user=user, password=password, port=port)
+        return _get_connection(postgres_credentials)
     except (Exception, psycopg2.DatabaseError) as error:
         raise ConnectionError(error) from error
 
 
+def _get_connection(postgres_credentials):
+    host = postgres_credentials.host
+    database = postgres_credentials.database
+    user = postgres_credentials.user
+    password = postgres_credentials.password
+    port = postgres_credentials.port
+
+    return psycopg2.connect(host=host, database=database, user=user, password=password, port=port)
+
+
 def query_database(
     connection: psycopg2.connect, query: str, params: tuple | None = None, close_connection: bool = True
 ) -> list:
